% Solve an Input-Output Fitting problem with a Neural Network
% Script generated by Neural Fitting app
% Created Mon Jan 19 12:43:17 CET 2015
%
% This script assumes these variables are defined:
%
%   ANN_in - input data.
%   ANN_out - target data.

%global ANN_in ANN_out

% Choose a Training Function
% For a list of all training functions type: help nntrain
% 'trainlm' is usually fastest.
% 'trainbr' takes longer but may be better for challenging problems.
% 'trainscg' uses less memory. NFTOOL falls back to this in low memory situations.
trainFcn = 'trainbr';  % Bayesian Regularization

% Create a Fitting Network
hiddenLayerSize = [10];
net = fitnet(hiddenLayerSize,trainFcn);

% Choose Input and Output Pre/Post-Processing Functions
% For a list of all processing functions type: help nnprocess
    % !Hides post- & preprocessing as described in Stackoverflow thread so the length of weigth vector is known! 
%net.input.processFcns = {'removeconstantrows','mapminmax'};         
%net.output.processFcns = {'removeconstantrows','mapminmax'};       

% Setup Division of Data for Training, Validation, Testing
% For a list of all data division functions type: help nndivide
net.divideFcn = 'dividerand';   % Divide data randomly
net.divideMode = 'sample';      % Divide up every sample
net.divideParam.trainRatio = 89/100;
net.divideParam.valRatio = 1/100;
net.divideParam.testRatio = 10/100;

% Choose a Performance Function
% For a list of all performance functions type: help nnperformance
net.performFcn = 'mse';  % Mean squared error

% Choose Plot Functions
% For a list of all plot functions type: help nnplot
net.plotFcns = {'plotperform','plottrainstate','ploterrhist', ...
  'plotregression', 'plotfit'};

% Train the Network
net.trainParam.epochs   = 5000;
net.trainParam.showWindow   = 0;
net.trainParam.showCommandLine = 1;
net.trainParam.show = 500;
[net,tr] = train(net,ANN_in,ANN_out);

% Test the Network
y = net(ANN_in);
e = gsubtract(ANN_out,y);
performance = perform(net,ANN_out,y)

% Recalculate Training, Validation and Test Performance
trainTargets = ANN_out .* tr.trainMask{1};
valTargets = ANN_out  .* tr.valMask{1};
testTargets = ANN_out  .* tr.testMask{1};
trainPerformance = perform(net,trainTargets,y)
%valPerformance = perform(net,valTargets,y)
testPerformance = perform(net,testTargets,y)

% View the Network
% view(net)

% Plots
% Uncomment these lines to enable various plots.
figure, plotperform(tr)
%figure, plottrainstate(tr)
%figure, plotfit(net,ANN_in,ANN_out)
figure, plotregression(ANN_out,y)
%figure, ploterrhist(e)

% Deployment
% Change the (false) values to (true) to enable the following code blocks.
if (true)
  % Generate MATLAB function for neural network for application deployment
  % in MATLAB scripts or with MATLAB Compiler and Builder tools, or simply
  % to examine the calculations your trained neural network performs.
  genFunction(net,'Mastergrad/myNeuralNetworkFunction_nH');
  y = myNeuralNetworkFunction_nH(ANN_in);
end
if (false)
  % Generate a matrix-only MATLAB function for neural network code
  % generation with MATLAB Coder tools.
  %genFunction(net,'myNeuralNetworkFunction','MatrixOnly','yes');
  y = myNeuralNetworkFunction(ANN_in);
end
if (false)
  % Generate a Simulink diagram for simulation or deployment with.
  % Simulink Coder tools.
  gensim(net);
end
