function[Rts] = Modellskalering(Cr, Vs, k0, Cbd, Avs, S, Lwl, Cb, B, Ta, Tf)

%% --------------- Input Variables ------------------
%   Cr      Restmotstandskoeffisient
%   Vs      Hastighet i knop
%   k0      Formfaktor
%   Cbd     Motstandskoeffisient, tverr hekk
%   Avs     Projisert tverrskipsareal over VL
%   S       Vr skrogoverflate
%   Lwl     Vannlinjelengde
%   Ta      Dypgang akter
%   Tf      Dypgang forut

%% --------------- Skalering ------------------


if k0 == 0
    Phi = (Cb/Lwl)*sqrt(B*(Ta+Tf));
    k0  = 0.6*Phi + 145*Phi^(3.5)+1;    % MARINTEKs formel for formfaktor
    Vs  = Vs/0.514444444;               % For  rette opp feil i database
end

V       = Vs*0.514444444;               % Hastighet i m/s

Rn      = (V*Lwl)/(1.139*10^(-6));      % Reynolds tall

Cf      = 0.075/(log10(Rn)-2)^2;                          % Friksjonsmotstand
dCf     = max((110.31*(150*V)^(0.21)-403.33)*Cf^(2),0); % Tillegg for skrogruhet i fullskala
Ca      = -0.228*1e-3;                                  % MARINTEKs korrelasjonskoeffisient
Caa     = 0.001*Avs/S;                                  % Luftmotstandskoeffisient



Ct      = Cr*1e-3 + (Cf + dCf)*k0 + Ca + Caa + Cbd*1e-3;    % Totalmotstandskoeffisient
    
Rts     = Ct * 0.5*1025*(V^2)*S;                            % Total motstand i full skala
