function [K_Q, K_T, etta_0] = Wageningen_coeff(Ja, P_D, AeA0, Z)

%   | Function that calculates Kt, Kq and n0 based on Wageningen B-series |
% The calulations are based on polynomials derived by Oosterveld and Oosanen.

%   | Inputs |
%   Ja      - The propellers J-number ( Ja = Vs*(1-w)/(n*D) )
%   P_D     - Propeller Pitch-diameter ratio (P/D)
%   AeA0    - Blade area ratio (Ae/A0)
%   Z       - Number of propeller blades

% Read .csv file with polynomial coefficients
KQ      = csvread('KQpolynomial.csv',1,0);      % Get Coefficients for K_Q
KT      = csvread('KTpolynomial.csv',1,0);      % Get Coefficients for K_T

% Write out size of matrices
[n1, n2]    = size(KQ);
[m1, m2]    = size(KT);

% Initial values
K_Q         = 0;
K_T         = 0;

% Calculation of Coefficients
for i = 1:n1
    K_Q     = KQ(i,1) *(Ja^KQ(i,2)) *(P_D^KQ(i,3)) *(AeA0^KQ(i,4)) *(Z^KQ(i,5)) + K_Q;
end

for i = 1:m1
    K_T     = KT(i,1) *(Ja^KT(i,2)) *(P_D^KT(i,3)) *(AeA0^KT(i,4)) *(Z^KT(i,5)) + K_T;
end

% Calculation of n0 based on K_Q and K_T
etta_0  = Ja/(2*pi) *(K_T/K_Q);

end